pub struct NativeFilesystem { /* private fields */ }Expand description
A filesystem implementation that reads from the native OS filesystem.
This implementation provides async access to files on the local filesystem, with all asset paths resolved relative to a configured root directory. Currently uses blocking I/O operations wrapped in async functions.
Implementations