pub trait AssetManagerContext: DowncastSync { }Expand description
Trait for providing additional context to the asset manager.
This trait allows extending the asset manager with custom state while maintaining type safety through downcasting capabilities.
Implementations
Sourceimpl dyn AssetManagerContext
impl dyn AssetManagerContext
Sourcepub fn is<__T: AssetManagerContext>(&self) -> bool
pub fn is<__T: AssetManagerContext>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: AssetManagerContext>(
self: Box<Self>,
) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: AssetManagerContext>( self: Box<Self>, ) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: AssetManagerContext>(
self: Rc<Self>,
) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: AssetManagerContext>( self: Rc<Self>, ) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: AssetManagerContext>(&self) -> Option<&__T>
pub fn downcast_ref<__T: AssetManagerContext>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: AssetManagerContext>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: AssetManagerContext>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.
Sourcepub fn downcast_arc<__T: AssetManagerContext + Any + Send + Sync>(
self: Arc<Self>,
) -> Result<Arc<__T>, Arc<Self>>
pub fn downcast_arc<__T: AssetManagerContext + Any + Send + Sync>( self: Arc<Self>, ) -> Result<Arc<__T>, Arc<Self>>
Returns an Arc-ed object from an Arc-ed trait object if the underlying object is of
type __T. Returns the original Arc-ed trait if it isn’t.